==> nextcloud-15.0.5p1.tgz: nextcloud/apps/twofactor_backupcodes/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Ocorreu um erro ao gerar os códigos de backup",
    "Nextcloud backup codes" : "Códigos de backup do Nextcloud",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estes são os seus códigos de backup. Salve e/ou imprima-os, pois não será possível ler os códigos novamente mais tarde",
    "Save backup codes" : "Salvar códigos de backup",
    "Print backup codes" : "Imprimir códigos de backup",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Códigos de backup foram gerados. Foram usados {used} de um total de {total} códigos .",
    "Regenerate backup codes" : "Regerar códigos de backup",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se você regerar os códigos de backup, invalidará automaticamente os códigos antigos.",
    "Generate backup codes" : "Gerar códigos de backup",
    "You created two-factor backup codes for your account" : "Você criou os códigos de backup de dois fatores para sua conta.",
    "Second-factor backup codes" : "Códigos de backup segundo-fator",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Você ativou a autenticação de dois fatores, mas ainda não gerou códigos de backup. Certifique-se de fazer isso caso perca o acesso ao segundo fator.",
    "Backup code" : "Código de backup",
    "Use backup code" : "Usar o código de backup",
    "Two factor backup codes" : "Códigos de backup de dois fatores",
    "A two-factor auth backup codes provider" : "Um provedor de códigos de backup de autenticação de dois fatores",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use um dos códigos de backup que você salvou ao configurar a autenticação de dois fatores.",
    "Submit" : "Enviar",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Códigos de backup foram gerados. {{used}} de {{total}} códigos foram usados.",
    "activated" : "ativado",
    "updated" : "atualizado",
    "mounted" : "montado",
    "deactivated" : "desativado",
    "beforeCreate" : "beforeCreate",
    "created" : "criado",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "destruído",
    "beforeMount" : "beforeMount"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Você criou os códigos de backup de dois fatores para sua conta.",
    "Second-factor backup codes" : "Códigos de backup segundo-fator",
    "Generate backup codes" : "Gerar códigos de backup",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Você ativou a autenticação de dois fatores, mas ainda não gerou códigos de backup. Eles são necessários para restaurar o acesso à sua conta caso você perca seu segundo fator.",
    "Backup code" : "Código de backup",
    "Use backup code" : "Usar o código de backup",
    "Two factor backup codes" : "Códigos de backup de dois fatores",
    "A two-factor auth backup codes provider" : "Um provedor de códigos de backup de autenticação de dois fatores",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Códigos de backup foram gerados. Foram usados {used} de um total de {total} códigos.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estes são os seus códigos de backup. Salve e/ou imprima-os, pois não será possível ler os códigos novamente mais tarde",
    "Save backup codes" : "Salvar códigos de backup",
    "Print backup codes" : "Imprimir códigos de backup",
    "Regenerate backup codes" : "Regerar códigos de backup",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se você gerar novamente os códigos de backup, invalidará automaticamente os códigos antigos.",
    "An error occurred while generating your backup codes" : "Ocorreu um erro ao gerar os códigos de backup",
    "{name} backup codes" : "Códigos de backup {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use um dos códigos de backup que você salvou ao configurar a autenticação de dois fatores.",
    "Submit" : "Enviar",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Você ativou a autenticação de dois fatores, mas ainda não gerou códigos de backup. Certifique-se de fazer isso caso perca o acesso ao segundo fator.",
    "function" : "função"
},
"nplurals=2; plural=(n > 1);");
